rdopts - Read options from setup.cfg using setuptools
=======================================================

The package rdopts contains a simple command to read options from a
setuptools setup.cfg file.  To install it, simply use easy_install or
pip::

    #easy_install
    easy_install rdopts

    #pip
    pip install rdopts

For information on using this command once it's installed, run the following
command (from any python setup.py file)::

    python setup.py rdopts -h

This will show you all command-line options for rdopts.
